# Slot: slot_usage


the redefinition of a slot in the context of the containing class definition.

URI: [http://w3id.org/biolink/biolinkml/meta/slot_usage](slot_uri)
## Domain and Range

[ClassDefinition](ClassDefinition.md) -><sub>opt</sub> [[SlotDefinition](SlotDefinition.md)]
## Inheritance

## Children

## Used by

 * [ClassDefinition](ClassDefinition.md)
